<?php

namespace Drupal\commerce_shipping_colissimo\Api;

use GuzzleHttp\Exception\ClientException;

class LabelApi {

  private MultipartRestClient $multipartRestClient;

  public function __construct(MultipartRestClient $multipartRestClient) {
    $this->multipartRestClient = $multipartRestClient;
  }

  /**
   * @throws \Drupal\commerce_shipping_colissimo\Api\ColissimoApiException
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function generate(LabelGenerationPayload $payload): LabelGenerationResponse {
    try {
      $multipartResponse = $this->multipartRestClient->query('/sls-ws/SlsServiceWSRest/2.0/generateLabel', $payload, LabelGenerationResponse::class);
      $labelGenerationResponse = $multipartResponse->getData();
      assert($labelGenerationResponse instanceof LabelGenerationResponse);
      $labelGenerationResponse->files = $multipartResponse->getFiles();
      return $labelGenerationResponse;
    }
    catch (ClientException $e) {
      $response = $e->getResponse();
      if (!$response) {
        throw $e;
      }
      $body = $response->getBody()->getContents();
      if (!$body) {
        throw $e;
      }
      $json = json_decode($body, TRUE);
      if (empty($json['messages'][0]['messageContent'])) {
        throw $e;
      }
      throw new ColissimoApiException($json['messages'][0]['messageContent'], 0, $e);
    }
  }

}
